Commands used for profiling the expression of Hox genes in the brachiopod *Terebratalia transversa*.

List of software:

* Trimmomatic 0.32
* Trinity 2.0.6
* RSEM

# Transcriptome assembly

We have Illumina 100bp paired ends reads (Ttra1.fq.gz and Ttra2.fq.gz). Raw
data available at NCBI SRA: SRX1307070.

Trim reads for quality:

	java -jar /usr/local/src/Trimmomatic-0.32/trimmomatic-0.32.jar PE -threads 20 -phred64 -trimlog trim.log Ttra1.fq.gz Ttra2.fq.gz Ttra1_paired.fq.gz Ttra1_unpaired.fq.gz Ttra2_paired.fq.gz Ttra2_unpaired.fq.gz ILLUMINACLIP:/usr/local/src/Trimmomatic-0.32/adapters/TruSeq2-PE.fa:2:30:10:4 LEADING:28 TRAILING:28 SLIDINGWINDOW:4:15 MAXINFO:40:0.5 MINLEN:36 TOPHRED33 > trim.out 2>&1 &

Assemble trimmed reads with Trinity using digital normalization:

	/usr/local/src/trinityrnaseq-2.0.6/Trinity --seqType fq --max_memory 350G --left data/Ttra1_paired.fq.gz --right data/Ttra2_paired.fq.gz --CPU 16 --full_cleanup --normalize_reads > Trinity.out 2>&1 &

Assembly statistics:

```
################################
## Counts of transcripts, etc.
################################
Total trinity 'genes':	58758
Total trinity transcripts:	92652
Percent GC: 37.06

########################################
Stats based on ALL transcript contigs:
########################################

	Contig N10: 5577
	Contig N20: 4145
	Contig N30: 3327
	Contig N40: 2713
	Contig N50: 2180

	Median contig length: 524
	Average contig: 1124.40
	Total assembled bases: 104177704


#####################################################
## Stats based on ONLY LONGEST ISOFORM per 'GENE':
#####################################################

	Contig N10: 5706
	Contig N20: 4088
	Contig N30: 3133
	Contig N40: 2407
	Contig N50: 1799

	Median contig length: 380
	Average contig: 847.69
	Total assembled bases: 49808476
```

# Align and estimate abundance

We sequenced 50bp single end Illumina reads of 14 developmental stages from
spawnings of two different females (F1 and F2). To estimate abundance and
calculate gene expression levels, we used Trinity’s included scripts.

Prepare reference and estimate abundance of whole transcriptome:

	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --left ../data/Ttra1_paired.fq.gz --right ../data/Ttra2_paired.fq.gz --est_method RSEM --aln_method bowtie --trinity_mode --prep_reference > abundance.out 2>& 1&

Estimate abundance for each sample:

	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S01.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S01 > Ttra_F1_S01_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S02.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S02 > Ttra_F1_S02_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S03.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S03 > Ttra_F1_S03_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S04.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S04 > Ttra_F1_S04_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S05.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S05 > Ttra_F1_S05_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S06.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S06 > Ttra_F1_S06_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S07.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S07 > Ttra_F1_S07_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S08.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S08 > Ttra_F1_S08_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S09.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S09 > Ttra_F1_S09_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S10.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S10 > Ttra_F1_S10_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S11.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S11 > Ttra_F1_S11_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S12.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S12 > Ttra_F1_S12_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S13.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S13 > Ttra_F1_S13_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F1_S14.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F1_S14 > Ttra_F1_S14_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S01.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S01 > Ttra_F2_S01_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S02.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S02 > Ttra_F2_S02_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S03.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S03 > Ttra_F2_S03_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S04.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S04 > Ttra_F2_S04_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S05.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S05 > Ttra_F2_S05_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S06.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S06 > Ttra_F2_S06_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S07.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S07 > Ttra_F2_S07_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S08.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S08 > Ttra_F2_S08_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S09.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S09 > Ttra_F2_S09_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S10.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S10 > Ttra_F2_S10_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S11.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S11 > Ttra_F2_S11_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S12.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S12 > Ttra_F2_S12_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S13.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S13 > Ttra_F2_S13_abundance.out 2>& 1&
	/usr/local/src/trinityrnaseq-2.0.6/util/align_and_estimate_abundance.pl --transcripts ../Ttra_new.fa --seqType fq --single ../../profiling/data/Ttra_F2_S14.fastq.gz --est_method RSEM --aln_method bowtie --trinity_mode --output_prefix Ttra_F2_S14 > Ttra_F2_S14_abundance.out 2>& 1&

Build gene level matrix of abundance estimations using TMM normalization:

	/usr/local/src/trinityrnaseq-2.0.6/util/abundance_estimates_to_matrix.pl --est_method RSEM --out_prefix genes Ttra_F1_S01.genes.results Ttra_F1_S02.genes.results Ttra_F1_S03.genes.results Ttra_F1_S04.genes.results Ttra_F1_S05.genes.results Ttra_F1_S06.genes.results Ttra_F1_S07.genes.results Ttra_F1_S08.genes.results Ttra_F1_S09.genes.results Ttra_F1_S10.genes.results Ttra_F1_S11.genes.results Ttra_F1_S12.genes.results Ttra_F1_S13.genes.results Ttra_F1_S14.genes.results Ttra_F2_S01.genes.results Ttra_F2_S02.genes.results Ttra_F2_S03.genes.results Ttra_F2_S04.genes.results Ttra_F2_S05.genes.results Ttra_F2_S06.genes.results Ttra_F2_S07.genes.results Ttra_F2_S08.genes.results Ttra_F2_S09.genes.results Ttra_F2_S10.genes.results Ttra_F2_S11.genes.results Ttra_F2_S12.genes.results Ttra_F2_S13.genes.results Ttra_F2_S14.genes.results

# *Terebratalia transversa* Hox genes

Contig names for the Hox genes in the transcriptome assembly.

```
hox1: TR24696|c0_g1
hox2: TR41559|c0_g1
hox3: TR41106|c4_g1
hox4: TR35050|c0_g1
hox5: TR8323|c0_g1
hox6: TR16624|c1_g1
hox7: TR20675|c0_g1
hox8: TR13142|c0_g1
post1: TR13045|c0_g2
post2: TR22236|c0_g1
```

See file `rnaseq.r` for the data handling and plotting.
